Learn R Programming

CNLTreg (version 0.1-2)

CNLTreg-package: CNLTreg

Description

CNLTreg

Arguments

Details

The DESCRIPTION file: CNLTreg CNLTreg

The main routines of the package are denoisepermC and cnlt.reg which perform complex-valued lifting-based denoising, using a single or a multiple (chosen) number of lifting trajectories, respectively.

References

Hamilton, J., Nunes, M. A, Knight, M. I. and Fryzlewicz, P. (2018) Complex-valued wavelet lifting and applications. Technometrics, 60 (1), 48-60, DOI 10.1080/00401706.2017.1281846. For related literature on the lifting methodology adopted in the technique, see Nunes, M. A., Knight, M. I and Nason, G. P. (2006) Adaptive lifting for nonparametric regression. Stat. Comput. 16 (2), 143--159. Knight, M. I. and Nason, G. P. (2009) A 'nondecimated' wavelet transform. Stat. Comput. 19 (1), 1--16.

See Also

denoise denoiseperm nlt