Learn R Programming

CNLTreg (version 0.1-2)

orthpredfilters: Computes orthogonal filters

Description

Given a filter L, finds a second filter M, orthogonal to L and with unit norm

Usage

orthpredfilters(filter = c(0.5, 1, 0.5))

Arguments

filter

An initial filter L

Value

A matrix with two rows, the first row corresponding to L, the second corresponding to the orthogonal filter M.

Warning

At present only works with odd length filters

Details

See Hamilton et al. (2018), section 2.2.

References

Hamilton, J., Nunes, M. A., Knight, M. I. and Fryzlewicz, P. (2018) Complex-valued wavelet lifting and applications. Technometrics, 60 (1), 48-60, DOI 10.1080/00401706.2017.1281846.

See Also

fwtnppermC

Examples

Run this code
# NOT RUN {
# create a vector representing a filter for one neighbour either side of a removed point
# (equally weighted):

L = c(0.5, 1, 0.5)

# now work out a unit-norm filter orthogonal to L

out <- orthpredfilters(L)

# M should be the second row:

out[2,]

# }

Run the code above in your browser using DataLab